@@ -3,18 +3,22 @@
 #' This function returns an object of S3 class RobinHood and establishes a connection to a RobinHood account.
 #' It is a required input for every other function in the package.
 #'
-#' @param username user name or email
-#' @param password password
+#' @param username (string) account email address
+#' @param password (string) password
+#' @param mfa_code (string) mfa_code provided by your authentication app (required if mfa is enabled)
 #' @import httr magrittr
 #' @export
 #' @examples
 #' \dontrun{
 #' RH <- RobinHood("username", "password")
 #'}
-RobinHood <- function(username, password) {
+RobinHood <- function(username, password, mfa_code = NULL) {
+
+    # Dealing with nulls inside functions
+    mfa_code = ifelse(is.null(mfa_code), "000000", mfa_code)
 
     # Login to RobinHood, returns RobinHood object with access tokens
-    RH <- api_login(username, password)
+    RH <- api_login(username, password, mfa_code)
 
     # Get account data for the main purpose of returning the position url
     accounts <- api_accounts(RH)
