@@ -12,14 +12,13 @@
 #' RH <- RobinHood("username", "password")
 #'
 #' # Place an order, should generate an email confirmation
-#'x <- place_order_crypto(RH = RH,
-#'                  symbol = "GE",          # Ticker symbol you want to trade
-#'                  type = "market",        # Type of market order
-#'                  time_in_force = "gfd",  # Time period the order is good for (gfd: good for day)
-#'                  trigger = "immediate",  # Trigger or delay order
-#'                  price = 8.96,           # The highest price you are willing to pay
-#'                  quantity = 1,           # Number of shares you want
-#'                  side = "buy")           # buy or sell
+#' x <- place_order_crypto(RH = RH,
+#'                         symbol = "ETC",         # Ticker symbol
+#'                         type = "market",        # Type of market order (market, limit)
+#'                         time_in_force = "gtc",  # Time period (gfd: good for day)
+#'                         price = 1,              # The highest price you are willing to pay
+#'                         quantity = 1,           # Number of shares you want
+#'                         side = "buy")           # buy or sell
 #'
 #' # Cancel the order, should also generate an email confirmation
 #' cancel_order_crypto(RH, x$cancel_url)
@@ -33,7 +32,7 @@ cancel_order_crypto <- function(RH, cancel_url) {
   if (length(order_status) == 0) cat("Order Canceled")
 
   if (length(order_status) >  0) {
-    cat("You may have already canceled this order, check order_status()")
+    cat("You may have already canceled this order, check order_status_crypto()")
   }
 
 }
