@@ -28,29 +28,18 @@ get_quote <- function(RH, symbol, limit_output = TRUE) {
 
     # Trim output
     quotes <- quotes[, !names(quotes) %in% c("instrument")]
-    quotes$updated_at <-  lubridate::ymd_hms(quotes$updated_at)
 
     if (limit_output == TRUE) {
 
-        quotes <- quotes[, c("symbol", "last_trade_price")]
+        quotes <- quotes %>% dplyr::select(c("symbol", "last_trade_price"))
 
     } else {
 
-        quotes <- quotes[, c("symbol",
-                             "last_trade_price",
-                             "last_trade_price_source",
-                             "ask_price",
-                             "ask_size",
-                             "bid_price",
-                             "bid_size",
-                             "previous_close",
-                             "adjusted_previous_close",
-                             "previous_close_date",
-                             "last_extended_hours_trade_price",
-                             "trading_halted",
-                             "has_traded",
-                             "updated_at")]
-                         }
+        quotes <- quotes %>%
+          dplyr::select(c("symbol", "last_trade_price", "last_trade_price_source", "ask_price", "ask_size",
+                          "bid_price", "bid_size", "previous_close", "adjusted_previous_close", "previous_close_date",
+                          "last_extended_hours_trade_price", "trading_halted", "has_traded", "updated_at"))
+    }
 
     return(quotes)
 
